@@ -18,6 +18,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-require('./prebuilt_dev_only_entry');
+require('./no_transpilation');
 
-require('./babel_register');
\ No newline at end of file
+require('@kbn/optimizer').registerNodeAutoTranspilation();
\ No newline at end of file
